@@ -98,7 +98,7 @@ class ApemanModelServiceClient(object):
             logger.error(e.args[0].trailing_metadata)
             raise Exception(e.details(), e.args[0].trailing_metadata)
 
-        return response.modelInstanceTaskId
+        return response.model_instance_task_id
 
     def get_instance_task(self, model_instance_task_id: str = None, token: str = None):
         request = apeman_open_api_pb2.GetModelInstanceTaskRequest(
